import * as i0 from '@angular/core';
import { Injectable, Inject, Optional, inject, NgModule } from '@angular/core';
import * as i1 from '@angular/common/http';
import { HttpClient, HttpHandler, HttpBackend, HTTP_INTERCEPTORS, HttpClientModule } from '@angular/common/http';

function createInterceptorHandler(baseHandler, interceptors) {
    return interceptors.reduceRight((next, interceptor) => new HttpInterceptorHandler(next, interceptor), baseHandler);
}
class HttpInterceptorHandler {
    constructor(next, interceptor) {
        this.next = next;
        this.interceptor = interceptor;
    }
    handle(request) {
        return this.interceptor.intercept(request, this.next);
    }
}

class ForkableHttpClient extends HttpClient {
    constructor(baseHandler, interceptors) {
        super(createInterceptorHandler(baseHandler, interceptors || []));
        this.baseHandler = baseHandler;
        this.interceptors = interceptors || [];
    }
    fork(...interceptors) {
        return new ForkableHttpClient(this.baseHandler, [...this.interceptors, ...interceptors]);
    }
}
ForkableHttpClient.ɵprov = i0.ɵɵdefineInjectable({ factory: function ForkableHttpClient_Factory() { return new ForkableHttpClient(i0.ɵɵinject(i1.HttpBackend), i0.ɵɵinject(i1.HTTP_INTERCEPTORS, 8)); }, token: ForkableHttpClient, providedIn: "root" });
ForkableHttpClient.decorators = [
    { type: Injectable, args: [{ providedIn: 'root' },] }
];
ForkableHttpClient.ctorParameters = () => [
    { type: HttpHandler, decorators: [{ type: Inject, args: [HttpBackend,] }] },
    { type: Array, decorators: [{ type: Optional }, { type: Inject, args: [HTTP_INTERCEPTORS,] }] }
];
function forkHttpClient(parent, ...interceptors) {
    return parent.fork(...interceptors);
}

/**
 * Creates a factory function that can be used for the factory of a self-providing `InjectionToken` for `ForkableHttpClient`.
 *
 * @param   parent Optional parent `ForkableHttpClient` which should be forked to create the new `ForkableHttpClient` instance. If no
 *                 argument is provided for this parameter, then the default 'root' ForkableHttpClient will be used.
 * @returns        A factory function that creates and returns a new `ForkableHttpClient` instance. The factory function also has a `with`
 *                 function that can be called to add extra interceptors to the new HTTP client.
 */
function httpClient(parent) {
    const interceptors = [];
    const factory = (() => {
        return inject(parent || ForkableHttpClient).fork(...interceptors.map((interceptor) => inject(interceptor)));
    });
    factory.with = (...interceptorsToAdd) => {
        interceptors.push(...interceptorsToAdd);
        return factory;
    };
    return factory;
}

/**
 * @deprecated `ForkableHttpClient` is now self-providing in root, so there is no more need for importing `ForkableHttpClientModule`.
 * Instead make sure the `HttpClientModule` is imported.
 */
class ForkableHttpClientModule {
}
ForkableHttpClientModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    HttpClientModule,
                ],
            },] }
];

/**
 * Generated bundle index. Do not edit.
 */

export { ForkableHttpClient, ForkableHttpClientModule, HttpInterceptorHandler, createInterceptorHandler, forkHttpClient, httpClient };
//# sourceMappingURL=ngx-forkable-http-client.js.map
